@@ -122,10 +122,8 @@ mod test {
 
         #[test]
         fn get_default_sample() {
-            let root = Path::new(env!("CARGO_MANIFEST_DIR"))
-                .parent()
-                .expect("Could not get CARGO_MANIFEST_DIR");
-            let path = root.join("samples/hello-world");
+            let root = Path::new(env!("CARGO_MANIFEST_DIR"));
+            let path = root.join("tests/test-flows/hello-world");
             match FileProvider::find_file(&path, "context", &["toml"]) {
                 Ok(path_string) => {
                     let path = path_string
@@ -149,10 +147,8 @@ mod test {
 
         #[test]
         fn get_default_sample_full_path() {
-            let root = Path::new(env!("CARGO_MANIFEST_DIR"))
-                .parent()
-                .expect("Could not get CARGO_MANIFEST_DIR");
-            let path = root.join("samples/hello-world/context.toml");
+            let root = Path::new(env!("CARGO_MANIFEST_DIR"));
+            let path = root.join("tests/test-flows/hello-world/context.toml");
             let url = Url::from_file_path(path).expect("Could not create Url from path");
             let provider: &dyn Provider = &FileProvider;
             let resolved_url = provider
@@ -167,10 +163,8 @@ mod test {
 
         #[test]
         fn get_default_sample_full_path_without_extension() {
-            let root = Path::new(env!("CARGO_MANIFEST_DIR"))
-                .parent()
-                .expect("Could not get CARGO_MANIFEST_DIR");
-            let path = root.join("samples/hello-world/context");
+            let root = Path::new(env!("CARGO_MANIFEST_DIR"));
+            let path = root.join("tests/test-flows/hello-world/context");
             let url = Url::from_file_path(path).expect("Could not create Url from path");
             let provider: &dyn Provider = &FileProvider;
             let resolved_url = provider
@@ -188,10 +182,8 @@ mod test {
 
         #[test]
         fn get_default_sample_rom_dir() {
-            let root = Path::new(env!("CARGO_MANIFEST_DIR"))
-                .parent()
-                .expect("Could not get CARGO_MANIFEST_DIR");
-            let path = root.join("samples/hello-world");
+            let root = Path::new(env!("CARGO_MANIFEST_DIR"));
+            let path = root.join("tests/test-flows/hello-world");
             let url = Url::from_file_path(path.clone()).expect("Could not create Url from path");
             let provider: &dyn Provider = &FileProvider;
             let resolved_url = provider
@@ -208,10 +200,8 @@ mod test {
 
         #[test]
         fn get_by_last_path_segment() {
-            let root = Path::new(env!("CARGO_MANIFEST_DIR"))
-                .parent()
-                .expect("Could not get CARGO_MANIFEST_DIR");
-            let path = root.join("flowstdlib/control/compare_switch");
+            let root = Path::new(env!("CARGO_MANIFEST_DIR"));
+            let path = root.join("tests/test-flows/control/compare_switch");
             let url = Url::from_file_path(path.clone()).expect("Could not create Url from path");
             let provider: &dyn Provider = &FileProvider;
             let resolved_url = provider
